import React, { useEffect, useState } from "react";
import {
  Button,
  Form,
  Input,
  message,
  Modal,
  Select,
  Space,
  Table,
  Tag,
} from "antd";
import { observer } from "mobx-react-lite";
import { ExclamationCircleOutlined } from "@ant-design/icons";
import { useHistory } from "react-router-dom";
import { capitalize } from "lodash";
import { useStore } from "../utils/useStore";
import { LINKS } from "../routes/app";

export const PartnerComponent = observer((props) => {
  const store = useStore();
  const [form] = Form.useForm();
  const { Option } = Select;
  const history = useHistory();
  const [idData, setIdData] = useState("");
  const [isChangePassword, setIsChangePassword] = useState(false);
  const [confirmLoading, setConfirmLoading] = useState(false);
  const [isLoading, setIsLoading] = useState(false);

  useEffect(() => {
    const init = async () => {
      try {
        setIsLoading(true);
        await store.partner.getData();
        setIsLoading(false);
      } catch (e) {
        setIsLoading(false);
      }
    };

    init();
  }, []);

  const changeStatus = async (id, isActive) => {
    const status = isActive ? "inactive" : "active";
    const status2 = isActive ? "Inactivating" : "Activating";
    try {
      const response = await store.partner.changeStatus(id, status);

      response?.body?.statusCode === 201
        ? message.success(`Success ${status2} Partner`)
        : message.error(`Failed ${status2} Partner`);
    } catch (err) {
      console.log("error", err);
      message.error(`Failed ${status2} Partner`);
    }
  };

  const handleEditButton = (data) => {
    console.log(data, "isi data");
    form.setFieldsValue({
      name: data.name,
      npwp: data.npwp,
      address: data.address,
    });
    setIsChangePassword(false);
    store.partner.visibleModalPartner = true;
    setIdData(data.id);
  };

  const changePassword = (data) => {
    // form.setFieldsValue({
    //   name: data.name,
    //   npwp: data.npwp,
    //   address: data.address,

    // });
    setIsChangePassword(true);
    store.partner.visibleModalPartner = true;
    setIdData(data.id);
  };

  const columns = [
    {
      title: "Name",
      dataIndex: "name",
      key: "name",
    },
    {
      title: "Npwp",
      dataIndex: "npwp",
      key: "npwp",
    },
    {
      title: "Address",
      dataIndex: "address",
      key: "address",
    },
    {
      title: "Status",
      dataIndex: "status",
      key: "status",
      render: (text, record) => (
        <Tag
          color={record?.status === true ? "processing" : "#E3E8EE"}
          style={{ color: "#4F566B", cursor: "pointer" }}
        >
          {record?.status === true ? " ACTIVE" : "INACTIVE"}
        </Tag>
      ),
    },
    {
      title: "Action",
      key: "action",
      render: (text, record) => (
        <Space size="middle">
          <Button onClick={() => changeStatus(record?.id, record?.status)}>
            {record?.status === true ? "Inactive" : "Active"}
          </Button>
          <Button onClick={() => handleEditButton(record)}>Edit</Button>
          {/* <Button onClick={() => handleDelete(record.id)}>Delete</Button> */}
          <Button onClick={() => changePassword(record)}>
            Change Password
          </Button>
        </Space>
      ),
    },
  ];

  const deleteData = async (id) => {
    try {
      console.log(id);
      await store.partner.delete(id);
      message.success("Data Berhasil Dihapus");
      history.push(LINKS.PARTNER);
    } catch (err) {
      console.log("error", err);
      message.error("Gagal menghapus");
    }
  };

  const handleDelete = (id) => {
    Modal.confirm({
      title: "Are you sure delete this record?",
      icon: <ExclamationCircleOutlined />,
      okText: "Yes",
      okType: "primary",
      cancelText: "Cancel",
      onOk() {
        return deleteData(id);
      },
      onCancel() {
        console.log("Cancel");
      },
    });
  };

  const handleCancel = () => {
    setIdData("");
    store.partner.visibleModalPartner = false;
  };

  const handleSubmit = async (data) => {
    console.log(data, "isi data2");
    if (idData !== "") {
      setConfirmLoading(true);
      try {
        await store.partner.update(idData, data);
        message.success(isChangePassword ? "Failed Change Partner Password" : "Success Update Data Partner");
        //await store.partner.getData()
      } catch (e) {
        message.error(isChangePassword ? "Failed Change Partner Password" : "Failed Update Data Partner");
      }
      setConfirmLoading(false);
      store.partner.visibleModalPartner = false;
      setIdData("");
      form.resetFields();
    } else {
      setConfirmLoading(true);
      try {
        await store.partner.create(data);
        message.success("Success Add New Partner");
        //await store.partner.getData()
      } catch (e) {
        console.log(e, "apa errornya");
        message.error("Failed Add Partner");
      }
      setConfirmLoading(false);
      store.partner.visibleModalPartner = false;
      setIdData("");
      form.resetFields();
    }
  };
  return (
    <div>
      <Table
        style={{ textAlign: "center" }}
        columns={columns}
        dataSource={store.partner.data}
        bordered
        pagination={{
          pageSize: store.partner.pageSize,
          total: store.partner.total_data,
          current: store.partner.page + 1,
          showSizeChanger: true,
          simple: false,
        }}
        onChange={async (page) => {
          let pageNumber = page.current;
          store.partner.pageSize = page.pageSize;
          store.partner.page = pageNumber - 1;
          //store.membership.isLoading = true;
          await store.partner.getData();
          // store.membership.isLoading = false;
        }}
      />

      <Modal
        visible={store.partner.visibleModalPartner}
        title={
          isChangePassword
            ? "Change Member Password"
            : idData
            ? "Edit Partner"
            : "Create a new partner"
        }
        okText={idData ? "Edit" : "Create"}
        cancelText="Cancel"
        onCancel={() => {
          form.resetFields();
          handleCancel();
        }}
        onOk={() => {
          form
            .validateFields()
            .then((values) => {
              console.log(values, "isi form");
              handleSubmit(values);
              form.resetFields();
            })
            .catch((info) => {
              console.error("Validate Failed:", info);
            });
        }}
      >
        <Form form={form} layout="vertical">
          {!isChangePassword && (
            <Form.Item
              name="name"
              label="Name"
              rules={[
                idData
                  ? { required: false }
                  : { required: true, message: "Please input password name!" },
              ]}
            >
              <Input />
            </Form.Item>
          )}
          {((idData && isChangePassword) || !idData) && (
            <Form.Item
              name="password_account"
              label="Password Account"
              rules={[
                idData
                  ? { required: false }
                  : {
                      required: true,
                      message: "Please input password account!",
                    },
              ]}
            >
              <Input />
            </Form.Item>
          )}

          {!isChangePassword && (
            <>
              <Form.Item
                name="npwp"
                label="Npwp"
                rules={[
                  idData
                    ? { required: false }
                    : { required: true, message: "Please input npwp!" },
                ]}
              >
                <Input />
              </Form.Item>
              <Form.Item
                name="address"
                label="address"
                rules={[
                  idData
                    ? { required: false }
                    : {
                        required: true,
                        message: "Please input password address!",
                      },
                ]}
              >
                <Input />
              </Form.Item>
            </>
          )}
        </Form>
      </Modal>
    </div>
  );
});
